@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 import json
+import logging
 
 import requests
-from loguru import logger
 
 from notify.notification import Notification
 
+logger = logging.getLogger(__name__)
+
 
 class WeChat(Notification):
     """企业微信消息通知"""
